
/* Chrysalide - Outil d'analyse de fichiers binaires
 * module.c - intégration du répertoire custom en tant que module
 *
 * Copyright (C) 2023 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "module.h"


#include <assert.h>
#include <Python.h>


#include <plugins/pychrysalide/access.h>
#include <plugins/pychrysalide/helpers.h>


#include "add1505-shl5.h"
#include "enigma-murmur.h"
#include "imul21-add.h"
#include "imul83-add.h"
#include "sll1-add-hash32.h"
#include "sub-index1.h"
#include "sub42.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Intègre les modificateurs d'empreintes particulières à ROST. *
*                                                                             *
*  Retour      : Bilan de l'opération.                                        *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool register_apihashing_custom_modifiers(void)
{
    bool result;                            /* Bilan à retourner           */

    result = true;

    if (result) result = ensure_python_scan_add1505_shl5_modifier_is_registered();
    if (result) result = ensure_python_scan_enigma_murmur_modifier_is_registered();
    if (result) result = ensure_python_scan_imul21_add_modifier_is_registered();
    if (result) result = ensure_python_scan_imul83_add_modifier_is_registered();
    if (result) result = ensure_python_scan_sll1_add_hash32_modifier_is_registered();
    if (result) result = ensure_python_scan_sub42_modifier_is_registered();
    if (result) result = ensure_python_scan_sub_index1_modifier_is_registered();

    assert(result);

    return result;

}
